# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowTimelineResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'count': 'int',
        'timelines': 'list[TimelineInfo]'
    }

    attribute_map = {
        'count': 'count',
        'timelines': 'timelines'
    }

    def __init__(self, count=None, timelines=None):
        """ShowTimelineResponse

        The model defined in huaweicloud sdk

        :param count: 总数。
        :type count: int
        :param timelines: 时间轴列表。
        :type timelines: list[:class:`huaweicloudsdkdrs.v5.TimelineInfo`]
        """
        
        super(ShowTimelineResponse, self).__init__()

        self._count = None
        self._timelines = None
        self.discriminator = None

        if count is not None:
            self.count = count
        if timelines is not None:
            self.timelines = timelines

    @property
    def count(self):
        """Gets the count of this ShowTimelineResponse.

        总数。

        :return: The count of this ShowTimelineResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ShowTimelineResponse.

        总数。

        :param count: The count of this ShowTimelineResponse.
        :type count: int
        """
        self._count = count

    @property
    def timelines(self):
        """Gets the timelines of this ShowTimelineResponse.

        时间轴列表。

        :return: The timelines of this ShowTimelineResponse.
        :rtype: list[:class:`huaweicloudsdkdrs.v5.TimelineInfo`]
        """
        return self._timelines

    @timelines.setter
    def timelines(self, timelines):
        """Sets the timelines of this ShowTimelineResponse.

        时间轴列表。

        :param timelines: The timelines of this ShowTimelineResponse.
        :type timelines: list[:class:`huaweicloudsdkdrs.v5.TimelineInfo`]
        """
        self._timelines = timelines

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowTimelineResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
